@@ -98,10 +98,10 @@ struct HBR_unicamp_Guarana_Result* BR_unicamp_Guarana_Result_returnLong(jlong re
   return guarana_new_result_object(res_returned, op, wrap);
 }
 
-struct HBR_unicamp_Guarana_Result* BR_unicamp_Guarana_Result_returnFloat(jfloat res, struct HBR_unicamp_Guarana_Operation *op) {
+struct HBR_unicamp_Guarana_Result* BR_unicamp_Guarana_Result_returnFloat(jdouble res, struct HBR_unicamp_Guarana_Operation *op) {
   jvalue wrap;
   checkRetType(op, 'F');
-  wrap.f = res;
+  wrap.d = res;
   return guarana_new_result_object(res_returned, op, wrap);
 }
 
@@ -125,11 +125,49 @@ struct HBR_unicamp_Guarana_Result* BR_unicamp_Guarana_Result_returnVoid(struct H
   return guarana_new_result_object(res_returned, op, wrap);
 }
 
-struct HBR_unicamp_Guarana_Result* BR_unicamp_Guarana_Result_throwObject(struct Hjava_lang_Throwable *obj, struct HBR_unicamp_Guarana_Operation *op) {
+struct HBR_unicamp_Guarana_Result* BR_unicamp_Guarana_Result_throwObject(struct Hjava_lang_Throwable *obj, struct HBR_unicamp_Guarana_Operation *op_) {
   jvalue wrap;
-  checkNullOp(op);
+  checkNullOp(op_);
+  if (obj) do {
+      static Hjava_lang_Class *javaLangError = 0;
+      static Hjava_lang_Class *javaLangRuntimeException = 0;
+      Hjava_lang_Class *objclass = OBJECT_CLASS((Hjava_lang_Object*)obj);
+      NativeOperation *op;
+      if (javaLangError == 0)
+	javaLangError = lookupClass("java/lang/Error");
+      if (instanceof(javaLangError, objclass))
+	break;
+      if (javaLangRuntimeException == 0)
+	javaLangRuntimeException = lookupClass("java/lang/RuntimeException");
+      if (instanceof(javaLangRuntimeException, objclass))
+	break;
+      op = (NativeOperation*)op_;
+      switch (op->kind & op_kind_mask) {
+      case op_nop:
+	break;
+
+      case op_method_invocation:
+      case op_constructor_invocation:
+	{
+	  methods *meth = op->op_id.method;
+	  Hjava_lang_Class *decclass = meth->class;
+	  constIndex *excepts = meth->declared_exceptions;
+	  int i, nr = meth->ndeclared_exceptions;
+	  for (i = 0; i < nr; ++i) {
+	    if (instanceof(getClass(excepts[i], decclass), objclass))
+	      break;
+	  }
+	  if (i < nr)
+	    break;
+	}
+	/* do not break */
+	
+      default:
+	SignalError("java/lang/IllegalArgumentException", "invalid exception type");
+      }
+  } while (0);
   wrap.l = obj;
-  return guarana_new_result_object(res_thrown, op, wrap);
+  return guarana_new_result_object(res_thrown, op_, wrap);
 }
 
 jint BR_unicamp_Guarana_Result_getMode(struct HBR_unicamp_Guarana_Result *this) {
@@ -203,12 +241,12 @@ jchar BR_unicamp_Guarana_Result_getCharValue(struct HBR_unicamp_Guarana_Result *
   return this->res.i;
 }
 
-jfloat BR_unicamp_Guarana_Result_getFloatValue(struct HBR_unicamp_Guarana_Result *this_) {
+jdouble BR_unicamp_Guarana_Result_getFloatValueAsDouble(struct HBR_unicamp_Guarana_Result *this_) {
   NativeResult *this = (NativeResult*)this_;
 
   checkRet(this);
   checkRetType(this->op, 'F');
-  return this->res.f;
+  return this->res.d;
 }
 
 jdouble BR_unicamp_Guarana_Result_getDoubleValue(struct HBR_unicamp_Guarana_Result *this_) {
