@@ -1,4 +1,4 @@
-// $Id: Guarana.java,v 1.16 1998/06/08 10:14:05 oliva Exp $
+// $Id: Guarana.java,v 1.17 1998/09/09 07:45:57 oliva Exp $
 
 /* Copyright 1997,1998 Alexandre Oliva <oliva@dcc.unicamp.br>
  *
@@ -40,7 +40,7 @@ package BR.unicamp.Guarana;
     these classes reflexive, we may change this constraint.
 
     @author Alexandre Oliva
-    @version $Revision: 1.16 $  */
+    @version $Revision: 1.17 $  */
 public final class Guarana {
     static {
         System.loadLibrary("guarana");
@@ -420,6 +420,6 @@ public final class Guarana {
 	    return ""+object;
 	else
 	    return getClassName(getClass(object)) +
-		'@' + Integer.toString(hashCode(object), 16);
+		'@' + Integer.toHexString(hashCode(object));
     }
 }
