@@ -1,4 +1,4 @@
-// $Id: OperationFactory.java,v 1.9 1998/06/08 14:33:43 oliva Exp $
+// $Id: OperationFactory.java,v 1.10 1998/07/24 06:43:55 oliva Exp $
 
 /* Copyright 1997,1998 Alexandre Oliva <oliva@dcc.unicamp.br>
  *
@@ -42,7 +42,7 @@ import java.lang.reflect.Field;
     @see MetaObject#initialize
 
     @author Alexandre Oliva
-    @version $Revision: 1.9 $ */
+    @version $Revision: 1.10 $ */
 public abstract class OperationFactory {
     /** Should return the Object this OperationFactory creates
       Operations for.  For static Operations, it will be the target
@@ -215,6 +215,10 @@ public abstract class OperationFactory {
 	Operation, or if the replaced Operation was not intercepted
 	yet.
 
+	@exception IllegalArgumentException if the given Method does
+	not satisfy the exception propagation restrictions of the
+	replaced Operation.
+
 	@exception IllegalAccessException if the OperationFactory
 	refuses to create the requested Operation.  */
     public abstract Operation invoke(final Method method,
@@ -224,22 +228,26 @@ public abstract class OperationFactory {
 
     /** Creates a Constructor invocation Operation.
 
-      @param constructor the Constructor to be invoked.
+	@param constructor the Constructor to be invoked.
 
-      @param arguments the argument list to be passed to the
-      Constructor.
+	@param arguments the argument list to be passed to the
+	Constructor.
 
-      @param operation an Operation that should be replaced.  If it is
-      null, a non-replacement Operation is created.
+	@param operation an Operation that should be replaced.  If it
+	is null, a non-replacement Operation is created.
       
-      @return the new Operation.
+	@return the new Operation.
 
-      @exception IllegalArgumentException if the expected type of the
-      replaced Operation is not void, or if the replaced Operation was
-      not intercepted yet.
+	@exception IllegalArgumentException if the expected type of
+	the replaced Operation is not void, or if the replaced
+	Operation was not intercepted yet.
 
-      @exception IllegalAccessException if the OperationFactory
-      refuses to create the requested Operation.  */
+	@exception IllegalArgumentException if the given Method does
+	not satisfy the exception propagation restrictions of the
+	replaced Operation.
+
+	@exception IllegalAccessException if the OperationFactory
+	refuses to create the requested Operation.  */
     public abstract Operation construct(final Constructor constructor,
 					final Object[] arguments,
 					final Operation operation)
