@@ -1,4 +1,4 @@
-// $Id: Result.java,v 1.14 1998/06/08 10:14:26 oliva Exp $
+// $Id: Result.java,v 1.16 1998/07/24 06:44:00 oliva Exp $
 
 /* Copyright 1997,1998 Alexandre Oliva <oliva@dcc.unicamp.br>
  *
@@ -37,7 +37,7 @@ package BR.unicamp.Guarana;
     @see MetaObject#handle
 
     @author Alexandre Oliva
-    @version $Revision: 1.14 $  */
+    @version $Revision: 1.16 $  */
 public final class Result {
     static {
         System.loadLibrary("guarana");
@@ -199,6 +199,21 @@ public final class Result {
 					   final Operation operation)
 	throws IllegalArgumentException;
 
+    /** Builds the Result of the Operation.  This only exists because
+	Kaffe won't handle float arguments correctly.
+
+	@param returned contains the returned value of the Operation.
+
+	@param operation is the Operation this Result refers to.
+
+	@return a Result containing the returned value.
+
+	@exception IllegalArgumentException if the value does not have
+	the expected type.  */
+    private static native Result returnFloat(final double returned,
+					     final Operation operation)
+	throws IllegalArgumentException;
+
     /** Builds the Result of the Operation.
 
 	@param returned contains the returned value of the Operation.
@@ -209,9 +224,11 @@ public final class Result {
 
 	@exception IllegalArgumentException if the value does not have
 	the expected type.  */
-    public static native Result returnFloat(final float returned,
-					    final Operation operation)
-	throws IllegalArgumentException;
+    public static Result returnFloat(final float returned,
+				     final Operation operation)
+	throws IllegalArgumentException {
+	return returnFloat((double)returned, operation);
+    }
 
     /** Builds the Result of the Operation.
 
@@ -261,9 +278,15 @@ public final class Result {
 
 	@param operation is the Operation this Result refers to.
 
-	@return a Result containing the Throwable value.  */
+	@return a Result containing the Throwable value.
+
+	@exception IllegalArgumentException if the given Throwable is
+	neither a Error nor a RuntimeException, nor does it match the
+	exception declaration of the given Operation, if it is a
+	constructor or method invocation.  */
     public static native Result throwObject(final Throwable thrown,
-					    final Operation operation);
+					    final Operation operation)
+	throws IllegalArgumentException;
 
     /** This method obtains the mode of the Result.  It may be one of
 	noResultMode, inspectResultMode, modifyResultMode,
@@ -355,7 +378,20 @@ public final class Result {
 
 	@exception IllegalArgumentException if the result type is not
 	the requested one, or no returned value is available.  */
-    public native float getFloatValue()
+    public float getFloatValue()
+	throws IllegalArgumentException {
+	return (float)getFloatValueAsDouble();
+    }
+
+    /** Obtains the returned value from the Operation.  This only
+	exists because Kaffe won't handle float return values
+	correctly.
+
+	@return the result of the Operation.
+
+	@exception IllegalArgumentException if the result type is not
+	the requested one, or no returned value is available.  */
+    private native double getFloatValueAsDouble()
 	throws IllegalArgumentException;
 
     /** Obtains the returned value from the Operation.
